sobjects/test/unittest_supervising.py
branchstable
changeset 1902 d38a46498eb9
parent 1723 30c3a713ab61
child 1977 606923dff11b
--- a/sobjects/test/unittest_supervising.py	Fri May 22 00:58:04 2009 +0200
+++ b/sobjects/test/unittest_supervising.py	Fri May 22 01:05:08 2009 +0200
@@ -43,23 +43,23 @@
         data = re.sub('/\d+', '/EID', data)
         self.assertTextEquals('''user admin has made the following change(s):
 
-* added euser #EID (toto)
-  http://testing.fr/cubicweb/euser/toto
+* added cwuser #EID (toto)
+  http://testing.fr/cubicweb/cwuser/toto
 
 * added relation in_group from euser #EID to egroup #EID
 
 * deleted card #EID (une news !)
 
 * added relation bookmarked_by from bookmark #EID to euser #EID
 
 * updated comment #EID (#EID)
   http://testing.fr/cubicweb/comment/EID
 
 * deleted relation comments from comment #EID to card #EID
 
 * changed state of euser #EID (anon)
   from state activated to state deactivated
-  http://testing.fr/cubicweb/euser/anon''',
+  http://testing.fr/cubicweb/cwuser/anon''',
                               data)
         # check prepared email
         op._prepare_email()
@@ -43,23 +43,23 @@
 
-* added relation in_group from euser #EID to egroup #EID
+* added relation in_group from cwuser #EID to cwgroup #EID
 
 * deleted card #EID (une news !)
@@ -43,23 +43,23 @@
 * deleted card #EID (une news !)
 
-* added relation bookmarked_by from bookmark #EID to euser #EID
+* added relation bookmarked_by from bookmark #EID to cwuser #EID
 
 * updated comment #EID (#EID)
@@ -43,23 +43,23 @@
 * deleted relation comments from comment #EID to card #EID
 
-* changed state of euser #EID (anon)
+* changed state of cwuser #EID (anon)
   from state activated to state deactivated